.. highlight:: shell


============
Installation
============


At the command line::

    $ easy_install pynoorm

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv pynoorm
    $ pip install pynoorm
